TimedCacheModel class abstract

An interface that enforces a time-to-live (ttl) for cached data. Implementations can use didExpire to determine if the data is still valid.

Implementers

Constructors

TimedCacheModel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl Duration
The duration that determines how long the cache is valid.
no setter

Methods

didExpire(DateTime? lastCache) bool
Method to check if a cache expired by date. Checks if the cache has expired based on the provided lastCache.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited