vit_cache library
Support for doing something awesome.
More dartdocs go here.
Classes
-
MultiCacheItem<
T> - Represents a cached item with its value and creation time.
-
MultiTimedCacheModel<
K, V> - A cache model that supports multiple keys and values with a time-to-live (ttl).
-
SingularCache<
T> - A cache model for a single value with a time-to-live (ttl).
- TimedCacheModel
- An interface that enforces a time-to-live (ttl) for cached data. Implementations can use didExpire to determine if the data is still valid.